aboutsummaryrefslogtreecommitdiff
path: root/generic/OverlapMan.h
diff options
context:
space:
mode:
Diffstat (limited to 'generic/OverlapMan.h')
-rw-r--r--generic/OverlapMan.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/generic/OverlapMan.h b/generic/OverlapMan.h
index fb844d9..52ae439 100644
--- a/generic/OverlapMan.h
+++ b/generic/OverlapMan.h
@@ -36,7 +36,7 @@
/*
* This is the interface with the radar widget. To substitute
* a different overlap manager, it is necessary to conform to
* this API.
*/
@@ -56,7 +56,7 @@ OmRegister(void *w,
void
OmUnregister(void *w);
void
-OmProcessOverlap(void *radar,
+OmProcessOverlap(void *zinc,
int width,
int height,
double scale);
@@ -36,7 +36,7 @@
/*
- * This is the interface with the radar widget. To substitute
+ * This is the interface with the zinc widget. To substitute
* a different overlap manager, it is necessary to conform to
* this API.